@@ -29,6 +29,8 @@ summary.easycorrelation <- function(object, redundant = FALSE, stars = TRUE, ...
   # Transfer attributes
   attributes(out) <- c(attributes(out), attributes(object)[!names(attributes(object)) %in% c("names", "row.names", "class", names(attributes(out)))])
   attr(out, "stars") <- stars
+  attr(out, "redundant") <- redundant
+  attr(out, "coefficient_name") <- target_col
   class(out) <- c("easycormatrix", "see_easycormatrix", class(out))
   out
 }
@@ -37,6 +39,7 @@ summary.easycorrelation <- function(object, redundant = FALSE, stars = TRUE, ...
 
 #' @export
 as.table.easycorrelation <- function(x, ...) {
+  .Deprecated("summary(..., redundant = TRUE)")
   summary(x, redundant = TRUE)
 }
 
